@@ -40,13 +40,9 @@ fn to_js_import_name(ns: &str, mjs_mode: bool) -> String {
   wrap_js_str(&xs)
 }
 
-fn to_js_file_name(ns: &str, mjs_mode: bool) -> String {
+fn to_mjs_filename(ns: &str) -> String {
   let mut xs: String = String::from(ns);
-  if mjs_mode {
-    xs.push_str(".mjs");
-  } else {
-    xs.push_str(".js");
-  }
+  xs.push_str(".mjs");
   xs
 }
 
@@ -1206,7 +1202,6 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
     // reset index each file
     reset_js_gensym_index();
 
-    // let coreLib = "http://js.calcit-lang.org/calcit.core.js".escape()
     let core_lib = to_js_import_name("calcit.core", true); // TODO js_mode
 
     let mut defs_code = String::from(""); // code generated by functions
@@ -1347,7 +1342,7 @@ pub fn emit_js(entry_ns: &str, emit_path: &str) -> Result<(), String> {
     keywords_code.push_str(&snippets::tmpl_keywords_init(&kwd_arr, kwd_prefix));
     keywords_code.push('\n');
 
-    let js_file_path = code_emit_path.join(to_js_file_name(&ns, true)); // TODO mjs_mode
+    let js_file_path = code_emit_path.join(to_mjs_filename(&ns));
     let wrote_new = write_file_if_changed(
       &js_file_path,
       &format!(
